@@ -1,4 +1,4 @@
-test_that("multiplication works", {
+test_that("wdnet_to_igraph and igraph_to_wdnet", {
   set.seed(123)
   netwk0 <- rpanet(nstep = 1e3)
   g0 <- wdnet_to_igraph(netwk0)
@@ -7,9 +7,8 @@ test_that("multiplication works", {
   netwk2 <- igraph_to_wdnet(g1)
   g2 <- wdnet_to_igraph(netwk2)
   tmp <- c("edgelist", "node.attr", "edge.attr", "weighted", "directed")
-  expect_true(all(
-    igraph::identical_graphs(g0, g1),
-    igraph::identical_graphs(g0, g2),
-    identical(netwk0[tmp], netwk1[tmp]),
-    identical(netwk0[tmp], netwk2[tmp])))
+  expect_true(igraph::identical_graphs(g0, g1))
+  expect_true(igraph::identical_graphs(g0, g2))
+  expect_equal(netwk0[tmp], netwk1[tmp])
+  expect_equal(netwk0[tmp], netwk2[tmp])
 })
